// pb_data module for retrieving pushbutton data from the 
// Xilinx Multimedia board
// Based on Push Button Scan Data In (PB_SCAN_DATA_IN.v)
// by Xilinx, Inc. June 2001.
//
// Modifications to base design made by Blair Fort for
// ECE532 - University of Toronto.  Winter 2004.
//

module pb_data
(
reset,
//reset_interrupt,
PB_CLOCK_P,
PB_DATA_P,

interrupt,
pb_status,
startup
);

input 			reset;				// system reset
//input 			reset_interrupt;	// interrupt reset
input 			PB_CLOCK_P;			// data shift clock sourced by the CPLD
input 			PB_DATA_P;			// serial push button data from CPLD

output			interrupt;			// 1 - when there is new data, 0 - after reset or reset_interrupt
output [9:0]	pb_status;			// The status of the pushbuttons
output			startup;				// 1 - tells the CPLD to be fully operational, 0 - CPLD off

wire				interrupt;
wire	[9:0]		pb_status;
wire				startup; 

wire 				reset;
wire				reset_interrupt;
wire 				pb_data;
wire 				pb_shift_clock;

wire				pb_reset_interrupt;		
reg				interrupt_reg;
reg [9:0] 		data_shift_reg;

// create the internal signals from the ports
assign pb_shift_clock 		= PB_CLOCK_P;
assign pb_data 				= PB_DATA_P;
assign pb_reset_interrupt	= reset | reset_interrupt;

//  turn the CPLD on
assign startup				= 1'b1;

// latch the data transmitted by the CPLD 
always @ (posedge reset or posedge pb_shift_clock) begin
	if (reset) begin
		data_shift_reg[9:0] <= 10'h000;
		end
	else begin
		data_shift_reg[9:1] <= data_shift_reg[8:0];
		data_shift_reg[0] <= pb_data;
		end
	end

// if data is transmitted by the CPLD set the interrupt high
always @ (posedge pb_reset_interrupt or posedge pb_shift_clock) begin
	if (pb_reset_interrupt) begin
		interrupt_reg <= 1'b0;
		end
	else begin
		interrupt_reg <= 1'b1;
		end
	end

// Route the pb data register and interrupt to the output
assign	pb_status	= data_shift_reg;
assign	interrupt	= interrupt_reg;

endmodule // pb_data



